@@ -91,15 +91,17 @@ def get_margins(disp_min: int, disp_max: int, cfg: Dict[str, dict]) -> xr.Datase
             r_marg += int(cfg["matching_cost"]["window_size"] / 2)  # type:ignore
             s_marg += int(cfg["matching_cost"]["window_size"] / 2)  # type:ignore
 
-        if cfg["refinement"]["refinement_method"] == "vfit":
-            r_marg[0] += 1
-            r_marg[2] += 1
-            s_marg[0] += 1
-            s_marg[2] += 1
+        if "refinement" in cfg:
+            if cfg["refinement"]["refinement_method"] == "vfit":
+                r_marg[0] += 1
+                r_marg[2] += 1
+                s_marg[0] += 1
+                s_marg[2] += 1
 
-        if cfg["filter"]["filter_method"] == "median":
-            r_marg += int(cfg["filter"]["filter_size"] / 2)  # type:ignore
-            s_marg += int(cfg["filter"]["filter_size"] / 2)  # type:ignore
+        if "filter" in cfg:
+            if cfg["filter"]["filter_method"] == "median":
+                r_marg += int(cfg["filter"]["filter_size"] / 2)  # type:ignore
+                s_marg += int(cfg["filter"]["filter_size"] / 2)  # type:ignore
 
     # Same margin for left and right: take the larger
     same_margin = list(map(lambda input: max(input[0], input[1]), zip(r_marg, s_marg)))
